import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { defaultEcogestureData } from '../../../tests/__mocks__/actionData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { profileData } from '../../../tests/__mocks__/profileData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ActionCard from './ActionCard'
import ActionList from './ActionList'

const mockStore = configureStore([])

const mockgetCustomActions = jest.fn()
const mockgetDefaultActions = jest.fn()

jest.mock('services/action.service', () => {
  return jest.fn(() => {
    return {
      getCustomActions: mockgetCustomActions,
      getDefaultActions: mockgetDefaultActions,
    }
  })
})

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

describe('ActionList component', () => {
  it('should be rendered correctly', () => {
    mockgetDefaultActions.mockResolvedValueOnce(defaultEcogestureData)
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionList setSelectedAction={jest.fn()} setShowList={jest.fn()} />
      </Provider>
    )
    expect(wrapper.find(ActionCard).exists())
  })
})
