import AxisBottom from 'components/Charts/AxisBottom'
import AxisRight from 'components/Charts/AxisRight'
import Bar from 'components/Charts/Bar'
import { scaleBand, ScaleBand, scaleLinear, ScaleLinear } from 'd3-scale'
import { FluidType } from 'enum/fluid.enum'
import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'
import { Dataload } from 'models'
import React, { useEffect, useRef, useState } from 'react'
import './elecHalfHourMonthlyAnalysis.scss'

interface ElecHalfHourChartProps {
  dataLoad: Dataload[]
  isWeekend: boolean
}

const ElecHalfHourChart = ({ dataLoad, isWeekend }: ElecHalfHourChartProps) => {
  const [width, setWidth] = useState<number>(0)
  const [height, setHeight] = useState<number>(0)
  const chartContainer = useRef<HTMLDivElement>(null)
  const marginLeft = 10
  const marginRight = 60
  const marginTop = 0
  const marginBottom = 30
  const getContentWidth = () => {
    return width - marginLeft - marginRight
  }

  const getContentHeight = () => {
    return height - marginTop - marginBottom
  }
  const getMaxLoad = () => {
    return dataLoad ? Math.max(...dataLoad.map((d: Dataload) => d.value)) : 0
  }

  const xScale: ScaleBand<string> = scaleBand()
    .domain(
      dataLoad.map((d: Dataload) =>
        d.date.toLocaleString(DateTime.DATETIME_SHORT)
      )
    )
    .range([0, getContentWidth()])
    .padding(0.1)

  const yScale: ScaleLinear<number, number> = scaleLinear()
    .domain([0, getMaxLoad()])
    .range([getContentHeight(), 0])

  useEffect(() => {
    function handleResize() {
      const maxWidth = 940
      const maxHeight = 170
      const _width = chartContainer.current
        ? chartContainer.current.offsetWidth > maxWidth
          ? maxWidth
          : chartContainer.current.offsetWidth
        : 400
      setWidth(_width)
      const _height = chartContainer.current
        ? chartContainer.current.offsetHeight > maxHeight
          ? maxHeight
          : chartContainer.current.offsetHeight
        : 200
      setHeight(_height)
    }
    handleResize()
    window.addEventListener('resize', handleResize)
    return () => window.removeEventListener('resize', handleResize)
  }, [])

  return (
    <div className="graph-elec-half-hour" ref={chartContainer}>
      <svg width={width} height={height}>
        <AxisRight
          fluidType={FluidType.ELECTRICITY}
          yScale={yScale}
          width={width}
          marginRight={marginRight}
          marginTop={marginTop}
          isAnalysis={true}
        />
        <g transform={`translate(${10},${0})`}>
          {dataLoad.map((value, index) => {
            return (
              <Bar
                key={index}
                index={index}
                dataload={value}
                compareDataload={null}
                fluidType={FluidType.ELECTRICITY}
                timeStep={TimeStep.HALF_AN_HOUR}
                showCompare={false}
                xScale={xScale}
                yScale={yScale}
                height={getContentHeight()}
                isSwitching={false}
                isDuel={false}
                weekdays={isWeekend ? 'weekend' : 'week'}
              />
            )
          })}
        </g>
        <AxisBottom
          data={dataLoad}
          timeStep={TimeStep.HALF_AN_HOUR}
          xScale={xScale}
          height={height}
          marginLeft={marginLeft}
          marginBottom={marginBottom}
          isDuel={false}
        />
      </svg>
    </div>
  )
}

export default ElecHalfHourChart
