import { Button } from '@material-ui/core'
import ElectricityBillIcon from 'assets/icons/visu/onboarding/electricity_bill.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import useKonnectorAuth from 'components/Hooks/useKonnectorAuth'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { Account, FluidStatus } from 'models'
import React, { Dispatch, useEffect } from 'react'
import { useDispatch, useSelector } from 'react-redux'
import { useNavigate } from 'react-router-dom'
import { AppActionsTypes, AppStore } from 'store'
import {
  setShouldRefreshConsent,
  updateSgeStore,
} from 'store/global/global.actions'
import { decoreText } from 'utils/decoreText'
interface SgeInitProps {
  fluidStatus: FluidStatus
}

const SgeInit: React.FC<SgeInitProps> = ({ fluidStatus }: SgeInitProps) => {
  const { t } = useI18n()
  const navigate = useNavigate()
  const konnectorSlug: string = fluidStatus.connection.konnectorConfig.slug
  const account: Account | null = fluidStatus.connection.account
  const { sgeConnect } = useSelector((state: AppStore) => state.ecolyo.global)

  const dispatch = useDispatch<Dispatch<AppActionsTypes>>()
  const [connect, update] = useKonnectorAuth(fluidStatus)

  useEffect(() => {
    async function launchConnect() {
      if (sgeConnect.shouldLaunchAccount) {
        dispatch(updateSgeStore({ ...sgeConnect, shouldLaunchAccount: false }))
        dispatch(setShouldRefreshConsent(false))
        if (!account) {
          await connect()
        } else {
          await update()
        }
      }
    }
    launchConnect()
  }, [account, connect, dispatch, sgeConnect, update])

  return (
    <div className="connection-form">
      <p className={`connection-form-title ${konnectorSlug} text-20-bold`}>
        {t(`auth.${konnectorSlug}.title`)}
      </p>
      <StyledIcon icon={ElectricityBillIcon} size={180} />
      <p
        className={`connection-form-subtitle ${konnectorSlug} text-16-regular`}
      >
        {decoreText(t('auth.' + `${konnectorSlug}` + '.bill'))}
      </p>

      <div className="connection-form-button">
        <Button
          aria-label={t(`auth.${konnectorSlug}.accessibility.connect`)}
          onClick={() => {
            navigate('/sge-connect')
          }}
          classes={{
            root: 'btn-highlight',
            label: 'text-16-bold',
          }}
        >
          {t(`auth.${konnectorSlug}.connect`)}
        </Button>
      </div>
    </div>
  )
}

export default SgeInit
