import { Link } from '@material-ui/core/'
import defaultIcon from 'assets/icons/visu/ecogesture/default.svg'
import StyledEcogestureCard from 'components/CommonKit/Card/StyledEcogestureCard'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { Ecogesture } from 'models'
import React, { useEffect, useState } from 'react'
import { Link as RouterLink } from 'react-router-dom'
import { importIconById } from 'utils/utils'
import './ecogestureCard.scss'
import EfficiencyRating from './EfficiencyRating'

interface EcogestureCardProps {
  ecogesture: Ecogesture
  selectionCompleted?: boolean
}

const EcogestureCard: React.FC<EcogestureCardProps> = ({
  ecogesture,
  selectionCompleted = false,
}: EcogestureCardProps) => {
  const [ecogestureIcon, setEcogestureIcon] = useState<string>('')
  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById(ecogesture.id, 'ecogesture')
      if (icon) {
        setEcogestureIcon(icon)
      } else {
        setEcogestureIcon(defaultIcon)
      }
    }
    if (ecogesture) {
      handleEcogestureIcon()
    }
  }, [ecogesture])

  return (
    <Link
      to={{
        pathname: `/ecogesture/${ecogesture.id}`,
      }}
      state={{ selectionCompleted }}
      component={RouterLink}
      className="ecogesture-list-item"
    >
      <StyledEcogestureCard>
        <div className="ec">
          <div className={`ec-content `}>
            <div className="ec-content-icon">
              <StyledIcon className="Icon" icon={ecogestureIcon} size={50} />
            </div>
            <div className="ec-content-short-name text-15-bold">
              {ecogesture.shortName}
            </div>
            <div className="ec-content-efficiency">
              <EfficiencyRating result={Math.round(ecogesture.efficiency)} />
            </div>
          </div>
        </div>
      </StyledEcogestureCard>
    </Link>
  )
}

export default EcogestureCard
