import Button from '@material-ui/core/Button'
import doingIcon from 'assets/icons/ico/doing-enabled.svg'
import objectiveIcon from 'assets/icons/ico/objective-enabled.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import React from 'react'
import { useNavigate } from 'react-router-dom'
import './ecogestureEmptyList.scss'

interface EcogestureEmptyListProps {
  setTab: React.Dispatch<React.SetStateAction<number>>
  isObjective: boolean
  isSelectionDone: boolean
  handleReinitClick: () => void
}
const EcogestureEmptyList: React.FC<EcogestureEmptyListProps> = ({
  setTab,
  isObjective,
  isSelectionDone,
  handleReinitClick,
}: EcogestureEmptyListProps) => {
  const { t } = useI18n()
  const navigate = useNavigate()
  return (
    <div className="ec-empty-container">
      <div className="ec-empty-content">
        <StyledIcon
          className="icon-big"
          icon={isObjective ? objectiveIcon : doingIcon}
          size={150}
        />
        <div className="text-16-normal text">
          {isObjective
            ? t(`ecogesture.emptyList.obj1${isSelectionDone ? '_done' : ''}`)
            : t(`ecogesture.emptyList.doing1${isSelectionDone ? '_done' : ''}`)}
        </div>
        <div className="text-16-normal text">
          {isObjective
            ? t(`ecogesture.emptyList.obj2${isSelectionDone ? '_done' : ''}`)
            : t(`ecogesture.emptyList.doing2${isSelectionDone ? '_done' : ''}`)}
        </div>
        <div className="btn-container">
          <Button
            aria-label={t('ecogesture.emptyList.btn1')}
            onClick={() => setTab(2)}
            classes={{
              root: 'btn-secondary-negative btn1',
              label: 'text-16-bold',
            }}
          >
            {t('ecogesture.emptyList.btn1')}
          </Button>

          {isSelectionDone && (
            <Button
              aria-label={t('ecogesture.reinit')}
              onClick={handleReinitClick}
              classes={{
                root: 'reinit-button btn-profile-next rounded',
                label: 'text-16-bold',
              }}
            >
              {t('ecogesture.reinit')}
            </Button>
          )}

          {!isSelectionDone && (
            <Button
              aria-label={t('ecogesture.emptyList.btn2')}
              onClick={() => {
                navigate('/ecogesture-form')
              }}
              classes={{
                root: 'btn-highlight btn2',
                label: 'text-16-bold',
              }}
            >
              {t('ecogesture.emptyList.btn2')}
            </Button>
          )}
        </div>
      </div>
    </div>
  )
}

export default EcogestureEmptyList
