import CozyBar from 'components/Header/CozyBar'
import { ScreenType } from 'enum/screen.enum'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import * as ModalAction from 'store/modal/modal.actions'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { modalStateData } from '../../../tests/__mocks__/modalStateData.mock'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

const mockStore = configureStore([])

describe('CozyBar component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <CozyBar />
      </Provider>
    )
    expect(wrapper.find('BarCenter')).toHaveLength(1)
    expect(wrapper.find('BarRight')).toHaveLength(1)
  })

  it('should call handleClickBack when back button is clicked', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <CozyBar displayBackArrow={true} />
      </Provider>
    )
    expect(wrapper.find('BarLeft')).toHaveLength(1)
    wrapper.find('BarLeft').find('.cv-button').first().simulate('click')
    expect(mockedNavigate).toHaveBeenCalled()
  })

  it('should call handleClickFeedbacks when feedback button is clicked', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        modal: modalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <CozyBar />
      </Provider>
    )
    const updateModalSpy = jest.spyOn(ModalAction, 'openFeedbackModal')
    wrapper.find('BarRight').find('.cv-button').first().simulate('click')
    expect(updateModalSpy).toHaveBeenCalledWith(true)
  })

  it('should not be rendered with screen type different from mobile', () => {
    const store = mockStore({
      ecolyo: {
        global: { ...globalStateData, screenType: ScreenType.DESKTOP },
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <CozyBar />
      </Provider>
    )
    expect(wrapper).toEqual({})
  })
})
