import Content from 'components/Content/Content'
import EcogestureFormEquipment from 'components/EcogestureForm/EcogestureFormEquipment'
import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import ProfileTypeFinished from 'components/ProfileType/ProfileTypeFinished'
import ProfileTypeFormMultiChoice from 'components/ProfileType/ProfileTypeFormMultiChoice'
import ProfileTypeFormNumber from 'components/ProfileType/ProfileTypeFormNumber'
import ProfileTypeFormNumberSelection from 'components/ProfileType/ProfileTypeFormNumberSelection'
import ProfileTypeFormSingleChoice from 'components/ProfileType/ProfileTypeFormSingleChoice'
import 'components/ProfileType/profileTypeView.scss'
import { FluidType } from 'enum/fluid.enum'
import {
  ConstructionYear,
  Floor,
  HotWaterEquipment,
  HotWaterFluid,
  HousingType,
  IndividualInsulationWork,
  IndividualOrCollective,
  OutsideFacingWalls,
  ProfileTypeFormType,
  ProfileTypeStepForm,
  ThreeChoicesAnswer,
  WarmingType,
} from 'enum/profileType.enum'
import { DateTime } from 'luxon'
import { ProfileType, ProfileTypeAnswer } from 'models/profileType.model'
import React, { useCallback, useEffect, useState } from 'react'
import { useSelector } from 'react-redux'
import ProfileTypeFormService from 'services/profileTypeForm.service'
import { AppStore } from 'store'
import ProfileTypeFormDateSelection from './ProfileTypeFormDateSelection'

const ProfileTypeView: React.FC = () => {
  const {
    profile,
    profileType: curProfileType,
    profileEcogesture: curProfileEcogesture,
  } = useSelector((state: AppStore) => state.ecolyo)

  const [headerHeight, setHeaderHeight] = useState<number>(0)
  const [profileType, setProfileType] = useState<ProfileType>({
    updateDate: DateTime.local()
      .setZone('utc', {
        keepLocalTime: true,
      })
      .startOf('month'),
    housingType: HousingType.INDIVIDUAL_HOUSE,
    constructionYear: ConstructionYear.BETWEEN_1975_AND_1989,
    area: '0',
    occupantsNumber: 1,
    outsideFacingWalls: OutsideFacingWalls.ONE,
    floor: Floor.NOT_APPLICABLE,
    heating: IndividualOrCollective.INDIVIDUAL,
    coldWater: IndividualOrCollective.INDIVIDUAL,
    individualInsulationWork: [IndividualInsulationWork.NONE],
    hasInstalledVentilation: ThreeChoicesAnswer.NO,
    hasReplacedHeater: ThreeChoicesAnswer.NO,
    hotWater: IndividualOrCollective.INDIVIDUAL,
    hotWaterEquipment: HotWaterEquipment.OTHER,
    warmingFluid: WarmingType.ELECTRICITY,
    hotWaterFluid: HotWaterFluid.ELECTRICITY,
    cookingFluid: FluidType.ELECTRICITY,
    equipments: [],
  })
  const [step, setStep] = useState<ProfileTypeStepForm>(
    ProfileTypeStepForm.HOUSING_TYPE
  )
  const [answerType, setAnswerType] = useState<ProfileTypeAnswer>({
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: '',
    choices: [],
  })

  const [isLoading, setIsLoading] = useState<boolean>(true)
  const [viewedStep, setViewedStep] = useState<number>(-1)

  const defineHeaderHeight = useCallback((height: number) => {
    setHeaderHeight(height)
  }, [])

  const setNextStep = useCallback(
    (_profileType?: ProfileType) => {
      let profileTypeFormService: ProfileTypeFormService
      if (_profileType) {
        setProfileType(_profileType)
        profileTypeFormService = new ProfileTypeFormService(_profileType)
        curProfileEcogesture.heating = _profileType.heating
        curProfileEcogesture.hotWater = _profileType.hotWater
        curProfileEcogesture.warmingFluid = _profileType.warmingFluid
      } else {
        // if equipments are updated, keep profileType as it is
        profileTypeFormService = new ProfileTypeFormService({
          ...profileType,
        })
      }
      const nextStep: ProfileTypeStepForm =
        profileTypeFormService.getNextFormStep(
          step,
          !profile.isProfileTypeCompleted
        )
      setIsLoading(true)
      if (nextStep > viewedStep) {
        setViewedStep(nextStep)
      }
      setStep(nextStep)
    },
    [
      curProfileEcogesture,
      profile.isProfileTypeCompleted,
      profileType,
      step,
      viewedStep,
    ]
  )

  const setPreviousStep = useCallback(
    (_profileType: ProfileType) => {
      setProfileType(_profileType)
      const profileTypeFormService = new ProfileTypeFormService(_profileType)
      const previousStep: ProfileTypeStepForm =
        profileTypeFormService.getPreviousFormStep(step)
      setIsLoading(true)
      setStep(previousStep)
    },
    [step]
  )

  const selectForm = () => {
    if (answerType.type === ProfileTypeFormType.SINGLE_CHOICE) {
      return (
        <ProfileTypeFormSingleChoice
          step={step}
          viewedStep={viewedStep}
          profileType={profileType}
          answerType={answerType}
          setNextStep={setNextStep}
          isProfileTypeComplete={profile.isProfileTypeCompleted}
          setPreviousStep={setPreviousStep}
        />
      )
    } else if (answerType.type === ProfileTypeFormType.MULTI_CHOICE) {
      return (
        <ProfileTypeFormMultiChoice
          step={step}
          viewedStep={viewedStep}
          profileType={profileType}
          answerType={answerType}
          setNextStep={setNextStep}
          setPreviousStep={setPreviousStep}
          isProfileTypeComplete={profile.isProfileTypeCompleted}
        />
      )
    } else if (answerType.type === ProfileTypeFormType.NUMBER) {
      return (
        <ProfileTypeFormNumber
          step={step}
          viewedStep={viewedStep}
          profileType={profileType}
          answerType={answerType}
          setNextStep={setNextStep}
          isProfileTypeComplete={profile.isProfileTypeCompleted}
          setPreviousStep={setPreviousStep}
        />
      )
    } else if (answerType.type === ProfileTypeFormType.NUMBER_SELECTION) {
      return (
        <ProfileTypeFormNumberSelection
          step={step}
          viewedStep={viewedStep}
          profileType={profileType}
          answerType={answerType}
          setNextStep={setNextStep}
          isProfileTypeComplete={profile.isProfileTypeCompleted}
          setPreviousStep={setPreviousStep}
        />
      )
    } else if (answerType.type === ProfileTypeFormType.DATE_SELECTION) {
      return (
        <ProfileTypeFormDateSelection
          step={step}
          viewedStep={viewedStep}
          profileType={profileType}
          answerType={answerType}
          setNextStep={setNextStep}
          isProfileTypeComplete={profile.isProfileTypeCompleted}
          setPreviousStep={setPreviousStep}
        />
      )
    } else if (answerType.type === ProfileTypeFormType.EQUIPMENT_SELECTION) {
      return (
        <EcogestureFormEquipment
          step={step}
          profileEcogesture={curProfileEcogesture}
          setNextStep={setNextStep}
          setPreviousStep={setPreviousStep}
        />
      )
    }
  }

  useEffect(() => {
    if (profile.isProfileTypeCompleted) {
      setProfileType(curProfileType)
    }
    const _answerType: ProfileTypeAnswer =
      ProfileTypeFormService.getAnswerForStep(step)
    setAnswerType(_answerType)
    setIsLoading(false)
  }, [step, profile, curProfileType])

  return (
    <>
      <CozyBar titleKey={'common.title_profiletype'} displayBackArrow={true} />
      <Header
        setHeaderHeight={defineHeaderHeight}
        desktopTitleKey={'common.title_profiletype'}
        displayBackArrow={true}
      />
      <Content height={headerHeight}>
        <div className={'profile-type-container'}>
          {isLoading ? null : step !== ProfileTypeStepForm.END ? (
            selectForm()
          ) : (
            <ProfileTypeFinished profileType={profileType} />
          )}
        </div>
      </Content>
    </>
  )
}

export default ProfileTypeView
