import QuizView from 'components/Quiz/QuizView'
import { UserQuizState } from 'enum/userQuiz.enum'
import { shallow } from 'enzyme'
import React from 'react'
import * as reactRedux from 'react-redux'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import QuizBegin from './QuizBegin'
import QuizFinish from './QuizFinish'
import QuizQuestion from './QuizQuestion'

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')
const mockUseSelector = jest.spyOn(reactRedux, 'useSelector')

describe('QuizView component', () => {
  it('should be rendered with QuizBegin component when quiz state = unlocked', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      quiz: { ...userChallengeData[0].quiz, state: UserQuizState.UNLOCKED },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<QuizView />)
    expect(wrapper.find(QuizBegin).exists()).toBeTruthy()
  })

  it('should be rendered with QuizQuestion component when quiz state = ongoing', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      quiz: { ...userChallengeData[0].quiz, state: UserQuizState.ONGOING },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<QuizView />)
    expect(wrapper.find(QuizQuestion).exists()).toBeTruthy()
  })

  it('should be rendered with QuizFinish component when quiz state = done', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      quiz: { ...userChallengeData[0].quiz, state: UserQuizState.DONE },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<QuizView />)
    expect(wrapper.find(QuizFinish).exists()).toBeTruthy()
  })

  it('should be rendered with QuizBegin component when quiz state = null', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      quiz: { ...userChallengeData[0].quiz, state: null },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<QuizView />)
    expect(wrapper.find(QuizBegin).exists()).toBeTruthy()
  })
})
