import Content from 'components/Content/Content'
import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import { UserQuizState } from 'enum/userQuiz.enum'
import { UserChallenge } from 'models'
import React, { useCallback, useState } from 'react'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'
import QuizBegin from './QuizBegin'
import QuizFinish from './QuizFinish'
import QuizQuestion from './QuizQuestion'

const QuizView: React.FC = () => {
  const [headerHeight, setHeaderHeight] = useState<number>(0)
  const { currentChallenge } = useSelector(
    (state: AppStore) => state.ecolyo.challenge
  )

  const defineHeaderHeight = useCallback((height: number) => {
    setHeaderHeight(height)
  }, [])

  const renderQuiz = (challenge: UserChallenge) => {
    switch (challenge.quiz.state) {
      case UserQuizState.UNLOCKED:
        return <QuizBegin userChallenge={challenge} />
      case UserQuizState.ONGOING:
        return <QuizQuestion userChallenge={challenge} />
      case UserQuizState.DONE:
        return <QuizFinish userChallenge={challenge} />
      default:
        return <QuizBegin userChallenge={challenge} />
    }
  }

  return (
    <>
      <CozyBar titleKey={'common.title_quiz'} displayBackArrow={true} />
      <Header
        setHeaderHeight={defineHeaderHeight}
        desktopTitleKey={'common.title_quiz'}
        displayBackArrow={true}
      />
      <Content height={headerHeight}>
        {currentChallenge && renderQuiz(currentChallenge)}
      </Content>
    </>
  )
}

export default QuizView
