import ActionView from 'components/Action/ActionView'
import ChallengeView from 'components/Challenge/ChallengeView'
import SgeConnectView from 'components/Connection/SGEConnect/SgeConnectView'
import DuelView from 'components/Duel/DuelView'
import EcogestureFormView from 'components/EcogestureForm/EcogestureFormView'
import EcogestureSelection from 'components/EcogestureSelection/EcogestureSelection'
import ExplorationView from 'components/Exploration/ExplorationView'
import Loader from 'components/Loader/Loader'
import UnSubscribe from 'components/Options/Unsubscribe/UnSubscribe'
import QuizView from 'components/Quiz/QuizView'
import TermsView from 'components/Terms/TermsView'
import { FluidType } from 'enum/fluid.enum'
import { TermsStatus } from 'models'
import React, { lazy, Suspense } from 'react'
import { Navigate, Route, Routes } from 'react-router-dom'

const ConsumptionView = lazy(() => import('components/Home/ConsumptionView'))
const EcogestureView = lazy(
  () => import('components/Ecogesture/EcogestureView')
)
const SingleEcogesture = lazy(
  () => import('components/Ecogesture/SingleEcogesture')
)
const OptionsView = lazy(() => import('components/Options/OptionsView'))
const LegalNoticeView = lazy(
  () => import('components/Options/LegalNotice/LegalNoticeView')
)
const GCUView = lazy(() => import('components/Options/GCU/GCUView'))
const AnalysisView = lazy(() => import('components/Analysis/AnalysisView'))
const ProfileTypeView = lazy(
  () => import('components/ProfileType/ProfileTypeView')
)

interface RouteProps {
  termsStatus: TermsStatus
}
const AppRoutes: React.FC<RouteProps> = ({ termsStatus }: RouteProps) => {
  return (
    <Suspense
      fallback={
        <div className="loaderContainer">
          <Loader />
        </div>
      }
    >
      <Routes>
        {!termsStatus.accepted && (
          <>
            <Route path="/terms" element={<TermsView />} />
            <Route path="*" element={<Navigate replace to="/terms" />} />
          </>
        )}
        {termsStatus.accepted && (
          <>
            <Route
              path="/consumption/electricity"
              element={<ConsumptionView fluidType={FluidType.ELECTRICITY} />}
            />
            <Route
              path="/consumption/water"
              element={<ConsumptionView fluidType={FluidType.WATER} />}
            />
            <Route
              path="/consumption/gas"
              element={<ConsumptionView fluidType={FluidType.GAS} />}
            />
            <Route
              path="/consumption"
              element={<ConsumptionView fluidType={FluidType.MULTIFLUID} />}
            />
            <Route path="/sge-connect" element={<SgeConnectView />} />
            <Route path="/challenges/duel" element={<DuelView />} />
            <Route path="/challenges/quiz" element={<QuizView />} />
            <Route
              path="/challenges/exploration"
              element={<ExplorationView />}
            />
            <Route path="/challenges/action" element={<ActionView />} />
            <Route path="/challenges/" element={<ChallengeView />} />
            <Route path="/ecogesture-form" element={<EcogestureFormView />} />
            <Route
              path="/ecogesture-selection"
              element={<EcogestureSelection />}
            />
            <Route
              path="/ecogesture/:ecogestureID/:tab"
              element={<SingleEcogesture />}
            />
            <Route
              path="/ecogesture/:ecogestureID"
              element={<SingleEcogesture />}
            />
            <Route path="/ecogestures" element={<EcogestureView />} />
            <Route path="/options/legalnotice" element={<LegalNoticeView />} />
            <Route path="/options/gcu" element={<GCUView />} />
            <Route path="/options/:connectParam" element={<OptionsView />} />
            <Route path="/options" element={<OptionsView />} />
            <Route path="/analysis" element={<AnalysisView />} />
            <Route path="/profiletype" element={<ProfileTypeView />} />
            <Route path="/unsubscribe" element={<UnSubscribe />} />
            <Route path="*" element={<Navigate replace to="/consumption" />} />
          </>
        )}
      </Routes>
    </Suspense>
  )
}

export default AppRoutes
