import { QueryResult } from 'cozy-client'
import { EnedisMonthlyAnalysisData } from 'models/enedisMonthlyAnalysis'
import { MaxPowerEntity } from 'models/maxPower.model'
import mockClient from '../../tests/__mocks__/client'
import {
  maxPowerData,
  mockDataLoadEnedisAnalysis,
  mockEnedisMonthlyAnalysis,
  mockEnedisMonthlyAnalysisArray,
} from '../../tests/__mocks__/enedisMonthlyAnalysisData.mock'
import EnedisMonthlyAnalysisDataService from './enedisMonthlyAnalysisData.service'

describe('Enedis Monthly Analysis service', () => {
  const emas = new EnedisMonthlyAnalysisDataService(mockClient)

  it('should return all Enedis Monthly Analysis', async () => {
    const mockQueryResult: QueryResult<EnedisMonthlyAnalysisData[]> = {
      data: mockEnedisMonthlyAnalysisArray,
      bookmark: '',
      next: false,
      skip: 0,
    }
    mockClient.query.mockResolvedValueOnce(mockQueryResult)
    const result = await emas.getAllEnedisMonthlyAnalysisData()
    expect(result).toEqual(mockEnedisMonthlyAnalysisArray)
  })
  it('should return no enedis analysis', async () => {
    const mockQueryResult: QueryResult<EnedisMonthlyAnalysisData[]> = {
      data: [],
      bookmark: '',
      next: false,
      skip: 0,
    }
    mockClient.query.mockResolvedValueOnce(mockQueryResult)
    const result = await emas.getLastEnedisMonthlyAnalysis()
    expect(result).toEqual([])
  })
  it('should return the last enedis analysis', async () => {
    const mockQueryResult: QueryResult<EnedisMonthlyAnalysisData> = {
      data: mockEnedisMonthlyAnalysis,
      bookmark: '',
      next: false,
      skip: 0,
    }
    mockClient.query.mockResolvedValueOnce(mockQueryResult)
    const result = await emas.getLastEnedisMonthlyAnalysis()
    expect(result).toEqual(mockEnedisMonthlyAnalysis)
  })
  it('should aggregate the analysis data to a dataload', () => {
    const result = emas.aggregateValuesToDataLoad(
      mockEnedisMonthlyAnalysisArray[0]
    )
    expect(result).toEqual(mockDataLoadEnedisAnalysis)
  })
  it('should get one analysis by Date', async () => {
    const mockQueryResult1: QueryResult<EnedisMonthlyAnalysisData[]> = {
      data: [mockEnedisMonthlyAnalysisArray[2]],
      bookmark: '',
      next: false,
      skip: 0,
    }
    mockClient.query.mockResolvedValueOnce(mockQueryResult1)
    const result = await emas.getEnedisMonthlyAnalysisByDate(2021, 8)
    expect(result).toEqual([mockEnedisMonthlyAnalysisArray[2]])
  })
  it('should create an enedis monthly analysis', async () => {
    const mockQueryResult: QueryResult<EnedisMonthlyAnalysisData> = {
      data: mockEnedisMonthlyAnalysisArray[0],
      bookmark: '',
      next: false,
      skip: 0,
    }
    mockClient.create.mockResolvedValueOnce(mockQueryResult)
    const result = await emas.createEnedisMonthlyAnalysisData(
      mockEnedisMonthlyAnalysisArray[0]
    )
    expect(result).toEqual(mockEnedisMonthlyAnalysisArray[0])
  })
  it('should fail create a enedis monthly analysis', async () => {
    mockClient.create.mockRejectedValue(new Error())
    await expect(
      emas.createEnedisMonthlyAnalysisData(mockEnedisMonthlyAnalysisArray[0])
    ).rejects.toThrow(new Error())
  })
  it('should get maxPower for a given month', async () => {
    const mockQueryResult: QueryResult<MaxPowerEntity[]> = {
      data: maxPowerData,
      bookmark: '',
      next: false,
      skip: 0,
    }
    mockClient.query.mockResolvedValueOnce(mockQueryResult)
    const result = await emas.getMaxPowerByDate(2021, 11)
    expect(result).toEqual(maxPowerData)
  })
})
