import * as Sentry from '@sentry/react'
import { Client } from 'cozy-client'
import logger from 'cozy-logger'
import logApp from 'utils/logger'

const logStack = logger.namespace('mailService')
export default class MailService {
  public async SendMail(
    client: Client,
    mailInfo: Record<string, any>
  ): Promise<void> {
    try {
      const jobCollection = client.collection('io.cozy.jobs')
      jobCollection.create('sendmail', mailInfo)
    } catch (error) {
      const errorMessage = `Failed to send mail`
      logStack('error', errorMessage)
      logApp.error(errorMessage)
      Sentry.captureException(errorMessage)
      throw new Error(errorMessage)
    }
  }
}
