import { Client, Q, QueryDefinition, QueryResult } from 'cozy-client'
import { PROFILEECOGESTURE_DOCTYPE } from 'doctypes'
import { ProfileEcogesture } from 'models/profileEcogesture.model'

export default class ProfileEcogestureService {
  private readonly _client: Client

  constructor(_client: Client) {
    this._client = _client
  }
  /**
   * Retrieve the ProfileEcogesture from db
   * @returns {ProfileEcogesture}
   */
  public async getProfileEcogesture(): Promise<ProfileEcogesture | null> {
    const query: QueryDefinition = Q(PROFILEECOGESTURE_DOCTYPE)
    const {
      data: [profileEcogesture],
    }: QueryResult<ProfileEcogesture[]> = await this._client.query(
      query.limitBy(1)
    )
    if (profileEcogesture) return profileEcogesture
    else return null
  }

  /**
   * Saves ProfileEcogesture in database
   * @returns {ProfileEcogesture}
   */
  public async updateProfileEcogesture(
    attributes: Partial<ProfileEcogesture>
  ): Promise<ProfileEcogesture | null> {
    const query: QueryDefinition = Q(PROFILEECOGESTURE_DOCTYPE)
    const {
      data: [doc],
    }: QueryResult<ProfileEcogesture[]> = await this._client.query(
      query.limitBy(1)
    )
    if (doc) {
      const { data: profileEcogesture }: QueryResult<ProfileEcogesture | null> =
        await this._client.save({
          ...doc,
          ...attributes,
        })
      if (profileEcogesture) return profileEcogesture
    }
    return null
  }
}
