import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'
import { Datachart } from 'models'
import { defaultAction } from 'store'

export const SET_CURRENT_DATACHART = 'SET_CURRENT_DATACHART'
export const SET_CURRENT_DATACHART_INDEX = 'SET_CURRENT_DATACHART_INDEX'
export const SET_CURRENT_INDEX = 'SET_CURRENT_INDEX'
export const SET_CURRENT_TIMESTEP = 'SET_CURRENT_TIMESTEP'
export const SET_LOADING = 'SET_LOADING'
export const SET_SELECTED_DATE = 'SET_SELECTED_DATE'

interface SetSelectedDate {
  type: typeof SET_SELECTED_DATE
  payload?: DateTime
}

interface SetCurrentTimeStep {
  type: typeof SET_CURRENT_TIMESTEP
  payload?: TimeStep
}

interface SetCurrentIndex {
  type: typeof SET_CURRENT_INDEX
  payload?: number
}

interface SetCurrentDataChart {
  type: typeof SET_CURRENT_DATACHART
  payload?: Datachart
}

interface SetCurrentDataChartIndex {
  type: typeof SET_CURRENT_DATACHART_INDEX
  payload?: number
}

interface SetLoading {
  type: typeof SET_LOADING
  payload?: boolean
}

export function setSelectedDate(date: DateTime): SetSelectedDate {
  return {
    type: SET_SELECTED_DATE,
    payload: date,
  }
}

export function setCurrentTimeStep(timeStep: TimeStep): SetCurrentTimeStep {
  return {
    type: SET_CURRENT_TIMESTEP,
    payload: timeStep,
  }
}

export function setCurrentIndex(currentIndex: number): SetCurrentIndex {
  return {
    type: SET_CURRENT_INDEX,
    payload: currentIndex,
  }
}

export function setCurrentDatachart(
  currentDatachart: Datachart
): SetCurrentDataChart {
  return {
    type: SET_CURRENT_DATACHART,
    payload: currentDatachart,
  }
}

export function setCurrentDatachartIndex(
  currentDatachartIndex: number
): SetCurrentDataChartIndex {
  return {
    type: SET_CURRENT_DATACHART_INDEX,
    payload: currentDatachartIndex,
  }
}

export function setLoading(isLoading: boolean): SetLoading {
  return {
    type: SET_LOADING,
    payload: isLoading,
  }
}

export type ChartActionTypes =
  | SetSelectedDate
  | SetCurrentTimeStep
  | SetCurrentIndex
  | SetCurrentDataChart
  | SetCurrentDataChartIndex
  | SetLoading
  | typeof defaultAction
