import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'
import { ChartState } from 'models/chart.model'
import { Reducer } from 'redux'
import {
  ChartActionTypes,
  SET_CURRENT_DATACHART,
  SET_CURRENT_DATACHART_INDEX,
  SET_CURRENT_INDEX,
  SET_CURRENT_TIMESTEP,
  SET_LOADING,
  SET_SELECTED_DATE,
} from 'store/chart/chart.actions'

const initialState: ChartState = {
  selectedDate: DateTime.local().endOf('minute').setZone('utc', {
    keepLocalTime: true,
  }),
  currentTimeStep: TimeStep.WEEK,
  currentIndex: 0,
  currentDatachart: { actualData: [], comparisonData: null },
  currentDatachartIndex: 0,
  loading: true,
}

export const chartReducer: Reducer<ChartState, ChartActionTypes> = (
  state = initialState,
  action
) => {
  if (action.payload == undefined) return state

  const updateState = (updates: Partial<ChartState>): ChartState => ({
    ...state,
    ...updates,
  })

  switch (action.type) {
    case SET_SELECTED_DATE:
      return updateState({ selectedDate: action.payload })

    case SET_CURRENT_TIMESTEP:
      return updateState({ currentTimeStep: action.payload })

    case SET_CURRENT_INDEX:
      return updateState({ currentIndex: action.payload })

    case SET_CURRENT_DATACHART:
      return updateState({ currentDatachart: action.payload })

    case SET_CURRENT_DATACHART_INDEX:
      return updateState({ currentDatachartIndex: action.payload })

    case SET_LOADING:
      return updateState({ loading: action.payload })

    default:
      return state
  }
}
